@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DataComparisonModules::Compare;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -9,228 +9,318 @@ our $results = [
     [
       {
         dataset     => "array len=1000",
-        errors      => 1.4e-05,
+        errors      => 2.4e-05,
         participant => "Data::Diff::diff",
-        rate        => 160,
+        rate        => 150,
         samples     => 20,
-        time        => 6.2,
+        time        => 6.9,
         vs_slowest  => 1,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 6.5e-06,
-        participant => "Data::Comparator::data_comparator",
-        rate        => 190,
-        samples     => 20,
-        time        => 5.1,
-        vs_slowest  => 1.2,
-      },
-      {
-        dataset     => "hash keys=1000",
-        errors      => 6.9e-06,
+        errors      => 2.4e-05,
         participant => "Data::Diff::diff",
-        rate        => 190,
+        rate        => 170,
         samples     => 20,
-        time        => 5.1,
+        time        => 5.8,
         vs_slowest  => 1.2,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 4e-06,
-        participant => "Data::Compare::Compare",
-        rate        => 209,
-        samples     => 20,
-        time        => 4.78,
-        vs_slowest  => 1.29,
+        errors      => 8.7e-06,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 180,
+        samples     => 21,
+        time        => 5.6,
+        vs_slowest  => 1.2,
       },
       {
-        dataset     => "array len=1000",
-        errors      => 9.4e-06,
-        participant => "Data::Comparator::data_comparator",
-        rate        => 220,
-        samples     => 21,
-        time        => 4.6,
+        dataset     => "hash keys=1000",
+        errors      => 9e-06,
+        participant => "Data::Compare::Compare",
+        rate        => 190,
+        samples     => 20,
+        time        => 5.2,
         vs_slowest  => 1.3,
       },
       {
         dataset     => "array len=1000",
-        errors      => 6.1e-06,
+        errors      => 1.7e-05,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 190,
+        samples     => 20,
+        time        => 5.2,
+        vs_slowest  => 1.3,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 1.8e-05,
         participant => "Data::Compare::Compare",
-        rate        => 290,
+        rate        => 250,
         samples     => 20,
-        time        => 3.4,
-        vs_slowest  => 1.8,
+        time        => 3.9,
+        vs_slowest  => 1.7,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 4.2e-06,
+        errors      => 9.9e-06,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 370,
+        rate        => 320,
         samples     => 20,
-        time        => 2.7,
-        vs_slowest  => 2.3,
+        time        => 3.1,
+        vs_slowest  => 2.2,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 4.1e-06,
+        errors      => 1e-05,
+        participant => "Data::Cmp::Numeric::cmp_data",
+        rate        => 350,
+        samples     => 20,
+        time        => 2.9,
+        vs_slowest  => 2.4,
+      },
+      {
+        dataset     => "hash keys=1000",
+        errors      => 2.8e-05,
+        participant => "Data::Cmp::StrOrNumeric::cmp_data",
+        rate        => 500,
+        samples     => 20,
+        time        => 2,
+        vs_slowest  => 3,
+      },
+      {
+        dataset     => "hash keys=1000",
+        errors      => 2.2e-06,
+        participant => "Data::Cmp::cmp_data",
+        rate        => 600,
+        samples     => 20,
+        time        => 1.7,
+        vs_slowest  => 4.1,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 5.4e-06,
         participant => "Data::Cmp::cmp_data",
         rate        => 620,
         samples     => 20,
         time        => 1.6,
-        vs_slowest  => 3.8,
+        vs_slowest  => 4.2,
       },
       {
         dataset     => "array len=1000",
-        errors      => 2.8e-06,
-        participant => "Data::Cmp::cmp_data",
-        rate        => 1000,
-        samples     => 25,
-        time        => 0.96,
-        vs_slowest  => 6.4,
+        errors      => 1.1e-05,
+        participant => "Data::Cmp::Numeric::cmp_data",
+        rate        => 630,
+        samples     => 20,
+        time        => 1.6,
+        vs_slowest  => 4.3,
       },
       {
         dataset     => "array len=1000",
-        errors      => 5.9e-06,
+        errors      => 2e-06,
+        participant => "Data::Cmp::StrOrNumeric::cmp_data",
+        rate        => 800,
+        samples     => 20,
+        time        => 1.2,
+        vs_slowest  => 5.5,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 2e-06,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 1300,
-        samples     => 21,
-        time        => 0.74,
-        vs_slowest  => 8.3,
+        rate        => 1200,
+        samples     => 20,
+        time        => 0.82,
+        vs_slowest  => 8.4,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 2.7e-07,
+        errors      => 2.1e-07,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 6100,
+        rate        => 5300,
         samples     => 20,
-        time        => 0.16,
-        vs_slowest  => 38,
+        time        => 0.19,
+        vs_slowest  => 36,
       },
       {
         dataset     => "array len=10",
-        errors      => 2.4e-07,
+        errors      => 4.8e-07,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 8200,
-        samples     => 25,
-        time        => 0.12,
-        vs_slowest  => 50,
+        rate        => 7000,
+        samples     => 20,
+        time        => 0.14,
+        vs_slowest  => 48,
       },
       {
         dataset     => "array len=10",
         errors      => 1.1e-07,
-        participant => "Data::Diff::diff",
-        rate        => 14000,
-        samples     => 20,
-        time        => 0.069,
-        vs_slowest  => 89,
-      },
-      {
-        dataset     => "hash keys=10",
-        errors      => 1.1e-07,
-        participant => "Data::Comparator::data_comparator",
-        rate        => 18000,
-        samples     => 20,
-        time        => 0.057,
-        vs_slowest  => 110,
-      },
-      {
-        dataset     => "hash keys=10",
-        errors      => 1e-07,
-        participant => "Data::Diff::diff",
-        rate        => 18000,
-        samples     => 22,
-        time        => 0.054,
-        vs_slowest  => 110,
-      },
-      {
-        dataset     => "hash keys=10",
-        errors      => 1.2e-07,
         participant => "Data::Compare::Compare",
-        rate        => 18000,
-        samples     => 25,
-        time        => 0.054,
-        vs_slowest  => 110,
+        rate        => 12000,
+        samples     => 20,
+        time        => 0.084,
+        vs_slowest  => 82,
       },
       {
         dataset     => "array len=10",
+        errors      => 8e-08,
+        participant => "Data::Diff::diff",
+        rate        => 13000,
+        samples     => 20,
+        time        => 0.076,
+        vs_slowest  => 90,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 8.9e-08,
+        participant => "Data::Compare::Compare",
+        rate        => 16000,
+        samples     => 29,
+        time        => 0.061,
+        vs_slowest  => 110,
+      },
+      {
+        dataset     => "hash keys=10",
         errors      => 1.1e-07,
         participant => "Data::Comparator::data_comparator",
-        rate        => 19000,
+        rate        => 17000,
         samples     => 20,
-        time        => 0.052,
+        time        => 0.059,
+        vs_slowest  => 120,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 1.1e-07,
+        participant => "Data::Diff::diff",
+        rate        => 18000,
+        samples     => 20,
+        time        => 0.056,
         vs_slowest  => 120,
       },
       {
         dataset     => "array len=10",
-        errors      => 5.2e-08,
-        participant => "Data::Compare::Compare",
-        rate        => 26000,
-        samples     => 21,
-        time        => 0.038,
-        vs_slowest  => 160,
+        errors      => 1.2e-07,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 18000,
+        samples     => 23,
+        time        => 0.054,
+        vs_slowest  => 130,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 2.7e-08,
-        participant => "Data::Cmp::cmp_data",
-        rate        => 63000,
-        samples     => 20,
-        time        => 0.016,
-        vs_slowest  => 390,
+        errors      => 2.2e-07,
+        participant => "Data::Cmp::Numeric::cmp_data",
+        rate        => 32000,
+        samples     => 22,
+        time        => 0.031,
+        vs_slowest  => 220,
       },
       {
         dataset     => "array len=10",
-        errors      => 5.5e-09,
+        errors      => 1.2e-07,
+        participant => "Data::Cmp::StrOrNumeric::cmp_data",
+        rate        => 36000,
+        samples     => 20,
+        time        => 0.027,
+        vs_slowest  => 250,
+      },
+      {
+        dataset     => "array len=10",
+        errors      => 7e-08,
         participant => "Data::Cmp::cmp_data",
-        rate        => 78300,
-        samples     => 29,
-        time        => 0.0128,
-        vs_slowest  => 482,
+        rate        => 45000,
+        samples     => 20,
+        time        => 0.022,
+        vs_slowest  => 310,
+      },
+      {
+        dataset     => "array len=10",
+        errors      => 1.4e-07,
+        participant => "Data::Cmp::Numeric::cmp_data",
+        rate        => 45000,
+        samples     => 20,
+        time        => 0.022,
+        vs_slowest  => 310,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 6e-08,
+        participant => "Data::Cmp::StrOrNumeric::cmp_data",
+        rate        => 49000,
+        samples     => 20,
+        time        => 0.021,
+        vs_slowest  => 330,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 2e-08,
+        participant => "Data::Cmp::cmp_data",
+        rate        => 62000,
+        samples     => 20,
+        time        => 0.016,
+        vs_slowest  => 430,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 1.1e-08,
+        participant => "Test::Deep::NoTest::eq_deeply",
+        rate        => 150000,
+        samples     => 32,
+        time        => 0.0069,
+        vs_slowest  => 1000,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 7.9e-10,
+        participant => "Data::Diff::diff",
+        rate        => 209000,
+        samples     => 20,
+        time        => 0.00478,
+        vs_slowest  => 1440,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 2.2e-08,
+        participant => "Data::Compare::Compare",
+        rate        => 210000,
+        samples     => 20,
+        time        => 0.0048,
+        vs_slowest  => 1400,
       },
       {
         dataset     => "simple scalar",
         errors      => 1.6e-09,
-        participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 167000,
-        samples     => 22,
-        time        => 0.00597,
-        vs_slowest  => 1030,
-      },
-      {
-        dataset     => "simple scalar",
-        errors      => 4.5e-11,
-        participant => "Data::Diff::diff",
-        rate        => 216980,
-        samples     => 21,
-        time        => 0.0046087,
-        vs_slowest  => 1336,
-      },
-      {
-        dataset     => "simple scalar",
-        errors      => 1.7e-09,
         participant => "Data::Comparator::data_comparator",
-        rate        => 311000,
-        samples     => 20,
-        time        => 0.00322,
-        vs_slowest  => 1910,
-      },
-      {
-        dataset     => "simple scalar",
-        errors      => 4.1e-09,
-        participant => "Data::Compare::Compare",
-        rate        => 440000,
-        samples     => 21,
-        time        => 0.0023,
-        vs_slowest  => 2700,
-      },
-      {
-        dataset     => "simple scalar",
-        errors      => 2.7e-09,
-        participant => "Data::Cmp::cmp_data",
-        rate        => 1100000,
+        rate        => 301000,
         samples     => 24,
-        time        => 0.00092,
-        vs_slowest  => 6700,
+        time        => 0.00332,
+        vs_slowest  => 2070,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 6.7e-09,
+        participant => "Data::Cmp::StrOrNumeric::cmp_data",
+        rate        => 500000,
+        samples     => 20,
+        time        => 0.002,
+        vs_slowest  => 3500,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 3.3e-09,
+        participant => "Data::Cmp::Numeric::cmp_data",
+        rate        => 650000,
+        samples     => 20,
+        time        => 0.0015,
+        vs_slowest  => 4500,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 4.2e-10,
+        participant => "Data::Cmp::cmp_data",
+        rate        => 1220000,
+        samples     => 20,
+        time        => 0.000821,
+        vs_slowest  => 8370,
       },
     ],
     {
@@ -355,7 +445,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2833.496,
+                                              speed                        => 2599.963,
                                               stepping                     => 4,
                                             },
                                             {
@@ -471,7 +561,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2525.366,
+                                              speed                        => 2599.963,
                                               stepping                     => 4,
                                             },
                                             {
@@ -587,7 +677,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2717.541,
+                                              speed                        => 2599.963,
                                               stepping                     => 4,
                                             },
                                             {
@@ -703,17 +793,19 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2741.552,
+                                              speed                        => 2599.963,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.41306090354919,
+      "func.elapsed_time"              => 2.45267081260681,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                                       => 1.041,
                                             "Bencher::Scenario::DataComparisonModules::Compare" => undef,
                                             "Benchmark::Dumb"                                   => 0.111,
-                                            "Data::Cmp"                                         => 0.003,
+                                            "Data::Cmp"                                         => 0.005,
+                                            "Data::Cmp::Numeric"                                => 0.005,
+                                            "Data::Cmp::StrOrNumeric"                           => 0.005,
                                             "Data::Comparator"                                  => undef,
                                             "Data::Compare"                                     => 1.25,
                                             "Data::Diff"                                        => 0.01,
@@ -727,7 +819,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "participant",
-                                            [0 .. 4],
+                                            [0 .. 6],
                                             "dataset",
                                             [0, 1, 2, 4, 5],
                                           ],
@@ -756,13 +848,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::DataComparisonModules::Compare",
-      "func.scenario_module_md5sum"    => "ccacde56f0b4862d35ca4269cb723634",
-      "func.scenario_module_mtime"     => 1534068588,
-      "func.scenario_module_sha1sum"   => "1576667af9b25b47ec1345caa4d016834acf8d8f",
-      "func.scenario_module_sha256sum" => "be561aa373d38659fa73db9185c23eb4065687283df32f0e09822bcd80fc6cbc",
-      "func.time_end"                  => 1534069423.04905,
+      "func.scenario_module_md5sum"    => "df1581024202a78adea41b0c57075fba",
+      "func.scenario_module_mtime"     => 1534070502,
+      "func.scenario_module_sha1sum"   => "57c793c5b044841b12269c1c17a1b9f215f14115",
+      "func.scenario_module_sha256sum" => "615febc11c46e987d76a745480d32756796ae53148179e49a56d1e9de67d1284",
+      "func.time_end"                  => 1534381748.95183,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1534069421.63599,
+      "func.time_start"                => 1534381746.49916,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
